@@ -25,15 +25,15 @@ from enum import Enum
 from typing import Dict, Iterator, List, Optional, Tuple
 
 from ..analysis import get_lucene_analyzer, JAnalyzer, JAnalyzerUtils
-from ..pyclass import autoclass, JString
-from ..search import Document
+from ..pyclass import autoclass
 from pyserini.util import download_prebuilt_index, get_sparse_indexes_info
-from pyserini.prebuilt_index_info import INDEX_INFO
+from pyserini.prebuilt_index_info import TF_INDEX_INFO, IMPACT_INDEX_INFO
 
 logger = logging.getLogger(__name__)
 
 
 # Wrappers around Anserini classes
+JDocument = autoclass('org.apache.lucene.document.Document')
 JIndexReader = autoclass('io.anserini.index.IndexReaderUtils')
 
 
@@ -51,6 +51,40 @@ class JIndexHelpers:
         return Counters(IndexCollection)
 
 
+class Document:
+    """Wrapper class for a Lucene ``Document``.
+
+    Parameters
+    ----------
+    document : JDocument
+        Underlying Lucene ``Document``.
+    """
+
+    def __init__(self, document):
+        if document is None:
+            raise ValueError('Cannot create a Document with None.')
+        self.object = document
+
+    def docid(self: JDocument) -> str:
+        return self.object.getField('id').stringValue()
+
+    def id(self: JDocument) -> str:
+        # Convenient alias for docid()
+        return self.object.getField('id').stringValue()
+
+    def lucene_document(self: JDocument) -> JDocument:
+        return self.object
+
+    def contents(self: JDocument) -> str:
+        return self.object.get('contents')
+
+    def raw(self: JDocument) -> str:
+        return self.object.get('raw')
+
+    def get(self: JDocument, field: str) -> str:
+        return self.object.get(field)
+
+
 class JGenerators(Enum):
     AclAnthologyGenerator = autoclass('io.anserini.index.generator.AclAnthologyGenerator')
     DefaultLuceneDocumentGenerator = autoclass('io.anserini.index.generator.DefaultLuceneDocumentGenerator')
@@ -150,7 +184,7 @@ class IndexReader:
 
     def __init__(self, index_dir):
         self.object = JIndexReader()
-        self.reader = self.object.getReader(JString(index_dir))
+        self.reader = self.object.getReader(index_dir)
 
     @classmethod
     def from_prebuilt_index(cls, prebuilt_index_name: str):
@@ -182,14 +216,20 @@ class IndexReader:
         reader = cls.from_prebuilt_index(prebuilt_index_name)
         stats = reader.stats()
 
-        if stats['documents'] != INDEX_INFO[prebuilt_index_name]['documents']:
-            raise ValueError('"documents" does not match!')
-
-        if stats['unique_terms'] != INDEX_INFO[prebuilt_index_name]['unique_terms']:
-            raise ValueError('"unique_terms" does not match!')
-
-        if stats['total_terms'] != INDEX_INFO[prebuilt_index_name]['total_terms']:
-            raise ValueError('"total_terms" does not match!')
+        if prebuilt_index_name in TF_INDEX_INFO:
+            if stats['documents'] != TF_INDEX_INFO[prebuilt_index_name]['documents']:
+                raise ValueError('"documents" does not match!')
+            if stats['unique_terms'] != TF_INDEX_INFO[prebuilt_index_name]['unique_terms']:
+                raise ValueError('"unique_terms" does not match!')
+            if stats['total_terms'] != TF_INDEX_INFO[prebuilt_index_name]['total_terms']:
+                raise ValueError('"total_terms" does not match!')
+        else:
+            if stats['documents'] != IMPACT_INDEX_INFO[prebuilt_index_name]['documents']:
+                raise ValueError('"documents" does not match!')
+            if stats['unique_terms'] != IMPACT_INDEX_INFO[prebuilt_index_name]['unique_terms']:
+                raise ValueError('"unique_terms" does not match!')
+            if stats['total_terms'] != IMPACT_INDEX_INFO[prebuilt_index_name]['total_terms']:
+                raise ValueError('"total_terms" does not match!')
 
         print(reader.stats())
         print('Statistics match!')
@@ -216,9 +256,9 @@ class IndexReader:
             List of tokens corresponding to the output of the analyzer.
         """
         if analyzer is None:
-            results = JAnalyzerUtils.analyze(JString(text.encode('utf-8')))
+            results = JAnalyzerUtils.analyze(text)
         else:
-            results = JAnalyzerUtils.analyze(analyzer, JString(text.encode('utf-8')))
+            results = JAnalyzerUtils.analyze(analyzer, text)
         tokens = []
         for token in results.toArray():
             tokens.append(token)
@@ -256,9 +296,9 @@ class IndexReader:
         if analyzer is None:
             analyzer = get_lucene_analyzer(stemming=False, stopwords=False)
 
-        term_map = self.object.getTermCountsWithAnalyzer(self.reader, JString(term.encode('utf-8')), analyzer)
+        term_map = self.object.getTermCountsWithAnalyzer(self.reader, term, analyzer)
 
-        return term_map.get(JString('docFreq')), term_map.get(JString('collectionFreq'))
+        return term_map.get('docFreq'), term_map.get('collectionFreq')
 
     def get_postings_list(self, term: str, analyzer=get_lucene_analyzer()) -> List[Posting]:
         """Return the postings list for a term.
@@ -276,9 +316,9 @@ class IndexReader:
             List of :class:`Posting` objects corresponding to the postings list for the term.
         """
         if analyzer is None:
-            postings_list = self.object.getPostingsListForAnalyzedTerm(self.reader, JString(term.encode('utf-8')))
+            postings_list = self.object.getPostingsListForAnalyzedTerm(self.reader, term)
         else:
-            postings_list = self.object.getPostingsListWithAnalyzer(self.reader, JString(term.encode('utf-8')),
+            postings_list = self.object.getPostingsListWithAnalyzer(self.reader, term,
                                                                     analyzer)
 
         if postings_list is None:
@@ -304,12 +344,12 @@ class IndexReader:
         Optional[Dict[str, int]]
             A dictionary with analyzed terms as keys and their term frequencies as values.
         """
-        doc_vector_map = self.object.getDocumentVector(self.reader, JString(docid))
+        doc_vector_map = self.object.getDocumentVector(self.reader, docid)
         if doc_vector_map is None:
             return None
         doc_vector_dict = {}
         for term in doc_vector_map.keySet().toArray():
-            doc_vector_dict[term] = doc_vector_map.get(JString(term.encode('utf-8')))
+            doc_vector_dict[term] = doc_vector_map.get(term)
         return doc_vector_dict
 
     def get_term_positions(self, docid: str) -> Optional[Dict[str, int]]:
@@ -328,12 +368,12 @@ class IndexReader:
         Optional[Dict[str, int]]
             A tuple contains a dictionary with analyzed terms as keys and corresponding posting list as values
         """
-        java_term_position_map = self.object.getTermPositions(self.reader, JString(docid))
+        java_term_position_map = self.object.getTermPositions(self.reader, docid)
         if java_term_position_map is None:
             return None
         term_position_map = {}
         for term in java_term_position_map.keySet().toArray():
-            term_position_map[term] = java_term_position_map.get(JString(term.encode('utf-8'))).toArray()
+            term_position_map[term] = java_term_position_map.get(term).toArray()
         return term_position_map
 
     def doc(self, docid: str) -> Optional[Document]:
@@ -350,7 +390,7 @@ class IndexReader:
         Optional[Document]
             :class:`Document` corresponding to the ``docid``.
         """
-        lucene_document = self.object.document(self.reader, JString(docid))
+        lucene_document = self.object.document(self.reader, docid)
         if lucene_document is None:
             return None
         return Document(lucene_document)
@@ -371,7 +411,7 @@ class IndexReader:
         Optional[Document]
             :class:`Document` whose ``field`` is ``id``.
         """
-        lucene_document = self.object.documentByField(self.reader, JString(field), JString(q))
+        lucene_document = self.object.documentByField(self.reader, field, q)
         if lucene_document is None:
             return None
         return Document(lucene_document)
@@ -389,7 +429,7 @@ class IndexReader:
         Optional[str]
             Raw document contents.
         """
-        return self.object.documentRaw(self.reader, JString(docid))
+        return self.object.documentRaw(self.reader, docid)
 
     def doc_contents(self, docid: str) -> Optional[str]:
         """Return the indexed document contents for a collection ``docid``.
@@ -404,7 +444,7 @@ class IndexReader:
         Optional[str]
             Index document contents.
         """
-        return self.object.documentContents(self.reader, JString(docid))
+        return self.object.documentContents(self.reader, docid)
 
     def compute_bm25_term_weight(self, docid: str, term: str, analyzer=get_lucene_analyzer(), k1=0.9, b=0.4) -> float:
         """Compute the BM25 weight of a term in a document. Specify ``analyzer=None`` for an already analyzed term,
@@ -429,12 +469,12 @@ class IndexReader:
             BM25 weight of the term in the document, or 0 if the term does not exist in the document.
         """
         if analyzer is None:
-            return self.object.getBM25AnalyzedTermWeightWithParameters(self.reader, JString(docid),
-                                                                       JString(term.encode('utf-8')),
+            return self.object.getBM25AnalyzedTermWeightWithParameters(self.reader, docid,
+                                                                       term,
                                                                        float(k1), float(b))
         else:
-            return self.object.getBM25UnanalyzedTermWeightWithParameters(self.reader, JString(docid),
-                                                                         JString(term.encode('utf-8')), analyzer,
+            return self.object.getBM25UnanalyzedTermWeightWithParameters(self.reader, docid,
+                                                                         term, analyzer,
                                                                          float(k1), float(b))
 
     def compute_query_document_score(self, docid: str, query: str, similarity=None):
@@ -492,6 +532,6 @@ class IndexReader:
 
         index_stats_dict = {}
         for term in index_stats_map.keySet().toArray():
-            index_stats_dict[term] = index_stats_map.get(JString(term.encode('utf-8')))
+            index_stats_dict[term] = index_stats_map.get(term)
 
         return index_stats_dict
