@@ -23,7 +23,7 @@ from urllib.request import urlretrieve
 
 from pyserini import search
 from pyserini.analysis import get_lucene_analyzer
-from pyserini.search import querybuilder
+from pyserini.search.lucene import querybuilder
 
 
 class TestQueryBuilding(unittest.TestCase):
@@ -40,7 +40,7 @@ class TestQueryBuilding(unittest.TestCase):
         tarball.extractall(self.index_dir)
         tarball.close()
 
-        self.searcher = search.SimpleSearcher(f'{self.index_dir}lucene-index.cacm')
+        self.searcher = search.LuceneSearcher(f'{self.index_dir}lucene-index.cacm')
 
     def testBuildBoostedQuery(self):
         term_query1 = querybuilder.get_term_query('information')
